"""Temperatures"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import constructor, utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.implicit import overridable
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private.utility import _1644

_TEMPERATURES = python_net_import(
    "SMT.MastaAPI.ElectricMachines.LoadCasesAndAnalyses", "Temperatures"
)

if TYPE_CHECKING:
    from typing import Any, Tuple, Type, TypeVar, Union

    Self = TypeVar("Self", bound="Temperatures")
    CastSelf = TypeVar("CastSelf", bound="Temperatures._Cast_Temperatures")


__docformat__ = "restructuredtext en"
__all__ = ("Temperatures",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_Temperatures:
    """Special nested class for casting Temperatures to subclasses."""

    __parent__: "Temperatures"

    @property
    def independent_reportable_properties_base(
        self: "CastSelf",
    ) -> "_1644.IndependentReportablePropertiesBase":
        pass

        return self.__parent__._cast(_1644.IndependentReportablePropertiesBase)

    @property
    def temperatures(self: "CastSelf") -> "Temperatures":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class Temperatures(_1644.IndependentReportablePropertiesBase["Temperatures"]):
    """Temperatures

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _TEMPERATURES

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def magnet_temperature(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "MagnetTemperature")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @magnet_temperature.setter
    @enforce_parameter_types
    def magnet_temperature(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "MagnetTemperature", value)

    @property
    def windings_temperature(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "WindingsTemperature")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @windings_temperature.setter
    @enforce_parameter_types
    def windings_temperature(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "WindingsTemperature", value)

    @property
    def cast_to(self: "Self") -> "_Cast_Temperatures":
        """Cast to another type.

        Returns:
            _Cast_Temperatures
        """
        return _Cast_Temperatures(self)
