"""SpringDamperSocket"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal import utility
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.system_model.connections_and_sockets.couplings import _2410

_SPRING_DAMPER_SOCKET = python_net_import(
    "SMT.MastaAPI.SystemModel.ConnectionsAndSockets.Couplings", "SpringDamperSocket"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.system_model.connections_and_sockets import _2339, _2359

    Self = TypeVar("Self", bound="SpringDamperSocket")
    CastSelf = TypeVar("CastSelf", bound="SpringDamperSocket._Cast_SpringDamperSocket")


__docformat__ = "restructuredtext en"
__all__ = ("SpringDamperSocket",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_SpringDamperSocket:
    """Special nested class for casting SpringDamperSocket to subclasses."""

    __parent__: "SpringDamperSocket"

    @property
    def coupling_socket(self: "CastSelf") -> "_2410.CouplingSocket":
        return self.__parent__._cast(_2410.CouplingSocket)

    @property
    def cylindrical_socket(self: "CastSelf") -> "_2339.CylindricalSocket":
        from mastapy._private.system_model.connections_and_sockets import _2339

        return self.__parent__._cast(_2339.CylindricalSocket)

    @property
    def socket(self: "CastSelf") -> "_2359.Socket":
        from mastapy._private.system_model.connections_and_sockets import _2359

        return self.__parent__._cast(_2359.Socket)

    @property
    def spring_damper_socket(self: "CastSelf") -> "SpringDamperSocket":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class SpringDamperSocket(_2410.CouplingSocket):
    """SpringDamperSocket

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _SPRING_DAMPER_SOCKET

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_SpringDamperSocket":
        """Cast to another type.

        Returns:
            _Cast_SpringDamperSocket
        """
        return _Cast_SpringDamperSocket(self)
